python_clustering: all you need for clustering
==============================================

python_clustering is a Python library based on sklearn and numpy. It
provides a wide range of functionality one might consider using during
clustering

Documentation
-------------

ToDo

Dependencies
------------

::

   Python >= 3.6
   -------------
   scipy>=1.7.3
   pandas>=1.3.4
   scikit-learn>=1.1.1
   numpy>=1.19.5
   arff==0.9
   pytablewriter==0.64.2
   pyod>=1.0.1
   requests>=2.28.1
   combo>=0.1.3
   tensorflow==2.7.0

Installation
------------

``pip install python-clustering``

Examples
--------

ToDo

Development
-----------

python-clustering development takes place on Github:
https://github.com/IvanReznikov/python-clustering Please submit bugs
that you encounter to the `issue
tracker <https://github.com/IvanReznikov/python-clustering/issues>`__

Further plans
-------------

1. Implement Task ideas regarding anomaly detection, calculating number
   of cluster using various methods, cluster ensembling and cluster
   similarity
2. Create functionality to detect pathwised cluster
3. Add experimental clustering methods